check_cvblocks: Build descriptive table of CV blocks

Description Usage Arguments Value Examples

Description

Build descriptive table of CV blocks

Usage

1
check_cvblocks(x, blocks)

Arguments

x

A vector of labels.

blocks

A vector of cv blocks.

Value

A matrix with a row for each cv block and a column for each condition label, along with margin totals and grand total.

Examples

1
2
3
4
5
x <- rep(c(0,1,2), c(49,949,874))
x <- x[sample(length(x))]
blocks <- cvblocker(x, k=10)
M <- check_cvblocks(x, blocks)
print(M)

crcox/cvblocker documentation built on May 12, 2019, 5:16 p.m.