Description Usage Arguments Value Examples
Build descriptive table of CV blocks
1 | check_cvblocks(x, blocks)
|
x |
A vector of labels. |
blocks |
A vector of cv blocks. |
A matrix with a row for each cv block and a column for each condition label, along with margin totals and grand total.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.